@@ -1,7 +1,7 @@
 use crate::errors::SortOrderError;
+use anyhow::Result;
 use regex::Regex;
 use std::collections::HashMap;
-use std::error::Error;
 use std::fs;
 use std::path::MAIN_SEPARATOR;
 
@@ -22,7 +22,7 @@ impl Source {
         pattern: &str,
         depth: Option<usize>,
         max_depth: Option<usize>,
-    ) -> Result<Self, Box<dyn Error>> {
+    ) -> Result<Self> {
         Ok(Self::Regex(
             Regex::new(pattern)?,
             depth.unwrap_or(pattern.chars().filter(|c| *c == MAIN_SEPARATOR).count() + 1),
@@ -30,18 +30,18 @@ impl Source {
         ))
     }
 
-    pub fn new_map(filename: &str) -> Result<Self, Box<dyn Error>> {
+    pub fn new_map(filename: &str) -> Result<Self> {
         let contents = fs::read_to_string(filename)?;
         Ok(Self::Map(serde_json::from_str(contents.as_str()).map(
             |map: HashMap<String, String>| map.into_iter().collect(),
         )?))
     }
 
-    pub fn new_sort(order: &str) -> Result<Self, Box<dyn Error>> {
+    pub fn new_sort(order: &str) -> Result<Self> {
         Ok(Self::Sort(match order.to_lowercase().as_str() {
             "asc" => SortOrder::Asc,
             "desc" => SortOrder::Desc,
-            _ => return Err(Box::new(SortOrderError::new(order))),
+            _ => return Err(SortOrderError::new(order).into()),
         }))
     }
 }
